@@ -7,7 +7,7 @@ from trcli.api.api_response_verify import ApiResponseVerify
 from trcli.cli import Environment
 from trcli.constants import (
     ProjectErrors,
-    FAULT_MAPPING,
+    FAULT_MAPPING, OLD_SYSTEM_NAME_AUTOMATION_ID, UPDATED_SYSTEM_NAME_AUTOMATION_ID,
 )
 from trcli.data_classes.data_parsers import MatchersParser
 from trcli.data_classes.dataclass_testrail import TestRailSuite, TestRailCase, ProjectData
@@ -40,7 +40,7 @@ class ApiRequestHandler:
 
     def check_automation_id_field(self, project_id: int) -> Union[str, None]:
         """
-        Checks if the automation_id field (custom_automation_id) is available for the project
+        Checks if the automation_id field (custom_automation_id or custom_case_automation_id) is available for the project
         :param project_id: the id of the project
         :return: error message
         """
@@ -48,17 +48,22 @@ class ApiRequestHandler:
         if not response.error_message:
             fields: List = response.response_text
             automation_id_field = next(
-                filter(lambda x: x["system_name"] == "custom_automation_id", fields),
+                    filter(
+                    lambda x: x["system_name"] in [OLD_SYSTEM_NAME_AUTOMATION_ID, UPDATED_SYSTEM_NAME_AUTOMATION_ID],
+                    fields
+                ),
                 None
             )
             if automation_id_field:
                 if automation_id_field["is_active"] is False:
                     return FAULT_MAPPING["automation_id_unavailable"]
                 if not automation_id_field["configs"]:
+                    self._active_automation_id_field = automation_id_field["system_name"]
                     return None
                 for config in automation_id_field["configs"]:
                     context = config["context"]
                     if context["is_global"] or project_id in context["project_ids"]:
+                        self._active_automation_id_field = automation_id_field["system_name"]
                         return None
                 return FAULT_MAPPING["automation_id_unavailable"]
             else:
@@ -227,9 +232,20 @@ class ApiRequestHandler:
         returned_sections, error_message = self.__get_all_sections(project_id, suite_id)
         if not error_message:
             missing_test_sections = False
+            sections_by_id = {section["id"]: section for section in returned_sections}
             sections_by_name = {section["name"]: section for section in returned_sections}
             section_data = []
             for section in self.suites_data_from_provider.testsections:
+                if self.environment.section_id:
+                    if section.section_id in sections_by_id.keys():
+                        section_json = sections_by_id[section.section_id]
+                        section_data.append({
+                            "section_id": section_json["id"],
+                            "suite_id": section_json["suite_id"],
+                            "name": section_json["name"],
+                        })
+                    else:
+                        missing_test_sections = True
                 if section.name in sections_by_name.keys():
                     section_json = sections_by_name[section.name]
                     section_data.append({
@@ -294,19 +310,21 @@ class ApiRequestHandler:
         if self.environment.case_matcher == MatchersParser.AUTO:
             test_cases_by_aut_id = {}
             for case in returned_cases:
-                aut_case_id = case["custom_automation_id"]
-                aut_case_id = aut_case_id if not aut_case_id else html.unescape(case["custom_automation_id"])
-                test_cases_by_aut_id[aut_case_id] = case
+                aut_case_id = case.get(OLD_SYSTEM_NAME_AUTOMATION_ID) or case.get(UPDATED_SYSTEM_NAME_AUTOMATION_ID)
+                if aut_case_id:
+                    aut_case_id = html.unescape(aut_case_id)
+                    test_cases_by_aut_id[aut_case_id] = case
             test_case_data = []
             for section in self.suites_data_from_provider.testsections:
                 for test_case in section.testcases:
-                    if test_case.custom_automation_id in test_cases_by_aut_id.keys():
-                        case = test_cases_by_aut_id[test_case.custom_automation_id]
+                    aut_id = test_case.custom_automation_id
+                    if aut_id in test_cases_by_aut_id.keys():
+                        case = test_cases_by_aut_id[aut_id]
                         test_case_data.append({
                             "case_id": case["id"],
                             "section_id": case["section_id"],
                             "title": case["title"],
-                            "custom_automation_id": test_case.custom_automation_id
+                            OLD_SYSTEM_NAME_AUTOMATION_ID: aut_id
                         })
                     else:
                         missing_cases_number += 1
@@ -377,6 +395,7 @@ class ApiRequestHandler:
             assigned_to_id: int = None,
             include_all: bool = False,
             refs: str = None,
+            case_ids: List[int] = None,
     ) -> Tuple[int, str]:
         """
         Creates a new test run.
@@ -386,6 +405,7 @@ class ApiRequestHandler:
         """
         add_run_data = self.data_provider.add_run(
             run_name,
+            case_ids=case_ids,
             milestone_id=milestone_id,
             assigned_to_id=assigned_to_id,
             include_all=include_all,
@@ -628,8 +648,11 @@ class ApiRequestHandler:
 
     def _add_case_and_update_data(self, case: TestRailCase) -> APIClientResult:
         case_body = case.to_dict()
-        if self.environment.case_matcher != MatchersParser.AUTO and "custom_automation_id" in case_body:
-            case_body.pop("custom_automation_id")
+        active_field = getattr(self, "_active_automation_id_field", None)
+        if active_field == UPDATED_SYSTEM_NAME_AUTOMATION_ID and OLD_SYSTEM_NAME_AUTOMATION_ID in case_body:
+            case_body[UPDATED_SYSTEM_NAME_AUTOMATION_ID] = case_body.pop(OLD_SYSTEM_NAME_AUTOMATION_ID)
+        if self.environment.case_matcher != MatchersParser.AUTO and OLD_SYSTEM_NAME_AUTOMATION_ID in case_body:
+            case_body.pop(OLD_SYSTEM_NAME_AUTOMATION_ID)
         response = self.client.send_post(f"add_case/{case_body.pop('section_id')}", case_body)
         if response.status_code == 200:
             case.case_id = response.response_text["id"]
@@ -684,7 +707,8 @@ class ApiRequestHandler:
             # Endpoints with pagination
             entities = entities + response.response_text[entity]
             if response.response_text["_links"]["next"] is not None:
-                return self.__get_all_entities(entity, link=response.response_text["_links"]["next"], entities=entities)
+                next_link = response.response_text["_links"]["next"].replace("limit=0", "limit=250")
+                return self.__get_all_entities(entity, link=next_link, entities=entities)
             else:
                 return entities, response.error_message
         else:
