@@ -86,7 +86,7 @@ PROMPT_MESSAGES = dict(
 )
 
 TOOL_VERSION = f"""TestRail CLI v{trcli.__version__}
-Copyright 2024 Gurock Software GmbH - www.gurock.com"""
+Copyright 2025 Gurock Software GmbH - www.gurock.com"""
 TOOL_USAGE = f"""Supported and loaded modules:
     - parse_junit: JUnit XML Files (& Similar)
     - parse_robot: Robot Framework XML Files
@@ -118,3 +118,7 @@ class RevertMessages:
     test_cases_not_deleted = "Unable to delete created test cases: {error}"
     run_deleted = "Deleted created run"
     run_not_deleted = "Unable to delete created run: {error}"
+
+OLD_SYSTEM_NAME_AUTOMATION_ID = "custom_automation_id"
+# field name mismatch on testrail side (can not reproduce in cloud version TestRail v9.1.2)
+UPDATED_SYSTEM_NAME_AUTOMATION_ID = "custom_case_automation_id"
\ No newline at end of file
