@@ -2,6 +2,7 @@ from beartype.typing import List, Dict, Optional
 
 from serde.json import to_dict
 
+from trcli.constants import OLD_SYSTEM_NAME_AUTOMATION_ID, UPDATED_SYSTEM_NAME_AUTOMATION_ID
 from trcli.data_classes.dataclass_testrail import TestRailSuite
 
 
@@ -193,7 +194,8 @@ class ApiDataProvider:
                 "case_id": 1,
                 "section_id": 1
                 "title": "testCase1",
-                "custom_automation_id": "className.testCase1"
+                "custom_automation_id": "className.testCase1",
+                "custom_case_automation_id": "className.testCase1"
             }
 
         """
@@ -204,10 +206,21 @@ class ApiDataProvider:
                     case
                     for sublist in testcases
                     for case in sublist
-                    if case.custom_automation_id == case_updater["custom_automation_id"]
+                    if case.custom_automation_id == case_updater[OLD_SYSTEM_NAME_AUTOMATION_ID]
                 ),
                 None,
             )
+            if matched_case is None:
+                matched_case = next(
+                    (
+                        case
+                        for sublist in testcases
+                        for case in sublist
+                        if hasattr(case, UPDATED_SYSTEM_NAME_AUTOMATION_ID)
+                        and case.custom_case_automation_id == case_updater.get(UPDATED_SYSTEM_NAME_AUTOMATION_ID)
+                    ),
+                    None,
+                )
             if matched_case is not None:
                 matched_case.case_id = case_updater["case_id"]
                 matched_case.result.case_id = case_updater["case_id"]
