@@ -1,6 +1,6 @@
 from pathlib import Path
 from abc import abstractmethod
-from typing import Union
+from beartype.typing import Union, List
 
 from trcli.cli import Environment
 from trcli.data_classes.dataclass_testrail import TestRailSuite
@@ -12,19 +12,17 @@ class FileParser:
     """
 
     def __init__(self, environment: Environment):
-        filepath = environment.file
-        self.filepath = filepath
-        self.check_file(filepath)
-        self.filename = Path(filepath).name
-        self.case_matcher = environment.case_matcher
+        self.filepath = self.check_file(environment.file)
+        self.filename = self.filepath.name
         self.env = environment
-        self.special = environment.special_parser
 
     @staticmethod
-    def check_file(filepath: Union[str, Path]):
-        if not Path(filepath).is_file():
+    def check_file(filepath: Union[str, Path]) -> Path:
+        filepath = Path(filepath)
+        if not filepath.is_file():
             raise FileNotFoundError("File not found.")
+        return filepath
 
     @abstractmethod
-    def parse_file(self) -> list[TestRailSuite]:
+    def parse_file(self) -> List[TestRailSuite]:
         raise NotImplementedError
