@@ -7,6 +7,7 @@ from xml.etree import ElementTree as etree
 from junitparser import JUnitXml, JUnitXmlError, Element, Attr
 
 from trcli.cli import Environment
+from trcli.constants import OLD_SYSTEM_NAME_AUTOMATION_ID
 from trcli.data_classes.data_parsers import MatchersParser, FieldsParser, TestRailCaseFieldsOptimizer
 from trcli.data_classes.dataclass_testrail import (
     TestRailCase,
@@ -149,6 +150,10 @@ class JunitParser(FileParser):
                         self.env.elog(error)
                         raise Exception(error)
                     case_fields_dict, error = FieldsParser.resolve_fields(case_fields)
+                    automation_id = (
+                            case_fields_dict.pop(OLD_SYSTEM_NAME_AUTOMATION_ID, None)
+                            or case._elem.get(OLD_SYSTEM_NAME_AUTOMATION_ID)
+                            or automation_id)
                     if error:
                         self.env.elog(error)
                         raise Exception(error)
@@ -230,3 +235,7 @@ class JunitParser(FileParser):
         self.env.log(f"Found {len(subsuites)} SauceLabs suites.")
 
         return [v for k, v in subsuites.items()]
+
+
+if __name__ == '__main__':
+    pass
